@@ -32,7 +32,6 @@
 #'
 cdisc_data <- function(...,
                        join_keys = teal.data::default_cdisc_join_keys[names(rlang::list2(...))],
-                       code = character(0),
-                       check) {
-  teal_data(..., join_keys = join_keys, code = code, check = check)
+                       code = character(0)) {
+  teal_data(..., join_keys = join_keys, code = code)
 }
